==> net.bluemind.p2.we.settings-4.9.3879.zip: net/bluemind/authentication/api/gwt/endpoint/APIKeysSockJsEndpoint.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.authentication.api.gwt.endpoint;

import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.commons.gwt.EndpointRequestCallback;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.json.client.JSONValue;
import com.google.gwt.json.client.JSONObject;
import net.bluemind.restbus.api.gwt.AsyncHandlerAdapter;
import java.util.List;
import java.util.Map;
import java.util.Set;
import net.bluemind.core.api.Stream;
import java.lang.Long;
import net.bluemind.restbus.api.gwt.GwtRestRequest;
import net.bluemind.restbus.api.gwt.GwtRestResponse;
import net.bluemind.restbus.api.gwt.RestBusImpl;

public class APIKeysSockJsEndpoint implements net.bluemind.authentication.api.IAPIKeysAsync {

	private String rootUri = "/api";

	private String baseUri;

    private String sessionId;

	public APIKeysSockJsEndpoint(String sessionId, String... pathVars) {
		String uri_ = "/auth/keys";
		this.sessionId = sessionId;
	

		baseUri = uri_;
	}

	public APIKeysSockJsEndpoint withRoot(String root) {
		this.rootUri = root;
		return this;
	}

	@Override
	public void store(String key, String displayName, final AsyncHandler<net.bluemind.authentication.api.APIKey> handler) {
		String postUri = "/{key}";

		postUri = postUri.replace("{key}", ""+key);
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		params.put("displayName", ""+displayName);
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"PUT",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<net.bluemind.authentication.api.APIKey>(handler) {
					@Override
			protected net.bluemind.authentication.api.APIKey handleResponse(
							JSONValue jsonValue) {
				return new net.bluemind.authentication.api.gwt.serder.APIKeyGwtSerDer().deserialize( jsonValue );
			}
		});

	}


	@Override
	public void list(final AsyncHandler<List<net.bluemind.authentication.api.APIKey>> handler) {
		String postUri = "";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"GET",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<List<net.bluemind.authentication.api.APIKey>>(handler) {
					@Override
			protected List<net.bluemind.authentication.api.APIKey> handleResponse(
							JSONValue jsonValue) {
				return new GwtSerDerUtils.ListSerDer<>(new net.bluemind.authentication.api.gwt.serder.APIKeyGwtSerDer()).deserialize( jsonValue );
			}
		});

	}


	@Override
	public void delete(String sid, final AsyncHandler<Void> handler) {
		String postUri = "/{sid}";

		postUri = postUri.replace("{sid}", ""+sid);
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"DELETE",rootUri + uri_,params, bodyContent);
		
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<Void>(handler) {
					@Override
			protected Void handleResponse(
							JSONValue jsonValue) {
				return null;
			}
		});

	}


	@Override
	public void get(String sid, final AsyncHandler<net.bluemind.authentication.api.APIKey> handler) {
		String postUri = "/{sid}";

		postUri = postUri.replace("{sid}", ""+sid);
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"GET",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<net.bluemind.authentication.api.APIKey>(handler) {
					@Override
			protected net.bluemind.authentication.api.APIKey handleResponse(
							JSONValue jsonValue) {
				return new net.bluemind.authentication.api.gwt.serder.APIKeyGwtSerDer().deserialize( jsonValue );
			}
		});

	}


	@Override
	public void create(String displayName, final AsyncHandler<net.bluemind.authentication.api.APIKey> handler) {
		String postUri = "";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		params.put("displayName", ""+displayName);
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"PUT",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<net.bluemind.authentication.api.APIKey>(handler) {
					@Override
			protected net.bluemind.authentication.api.APIKey handleResponse(
							JSONValue jsonValue) {
				return new net.bluemind.authentication.api.gwt.serder.APIKeyGwtSerDer().deserialize( jsonValue );
			}
		});

	}

	public net.bluemind.authentication.api.IAPIKeysPromise promiseApi() {
		return new APIKeysEndpointPromise(this);
	}

}

==> net.bluemind.p2.we.settings-5.5.3112.zip: net/bluemind/authentication/api/gwt/endpoint/APIKeysSockJsEndpoint.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.authentication.api.gwt.endpoint;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.http.client.URL;
import com.google.gwt.json.client.JSONValue;
import com.google.gwt.json.client.JSONObject;

import java.util.List;
import java.util.Map;
import java.util.Set;
import java.lang.Long;

import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.api.Stream;
import net.bluemind.core.commons.gwt.EndpointRequestCallback;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;
import net.bluemind.restbus.api.gwt.AsyncHandlerAdapter;
import net.bluemind.restbus.api.gwt.GwtRestRequest;
import net.bluemind.restbus.api.gwt.GwtRestResponse;
import net.bluemind.restbus.api.gwt.RestBusImpl;

public class APIKeysSockJsEndpoint implements net.bluemind.authentication.api.IAPIKeysAsync {

	private String rootUri = "/api";

	private String baseUri;

    private String sessionId;

	public APIKeysSockJsEndpoint(String sessionId, String... pathVars) {
		String uri_ = "/auth/keys";
		this.sessionId = sessionId;
	

		baseUri = uri_;
	}

	public APIKeysSockJsEndpoint withRoot(String root) {
		this.rootUri = root;
		return this;
	}

	@Override
	public void create(String displayName, final AsyncHandler<net.bluemind.authentication.api.APIKey> handler) {
		String postUri = "";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		params.put("displayName", URL.encodeQueryString(""+displayName));
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"PUT",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<net.bluemind.authentication.api.APIKey>(handler) {
					@Override
			protected net.bluemind.authentication.api.APIKey handleResponse(
							JSONValue jsonValue) {
				return new net.bluemind.authentication.api.gwt.serder.APIKeyGwtSerDer().deserialize( jsonValue );
			}
		});

	}


	@Override
	public void delete(String uid, final AsyncHandler<Void> handler) {
		String postUri = "/{uid}";

		postUri = postUri.replace("{uid}", URL.encodePathSegment(""+uid));
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"DELETE",rootUri + uri_,params, bodyContent);
		
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<Void>(handler) {
					@Override
			protected Void handleResponse(
							JSONValue jsonValue) {
				return null;
			}
		});

	}


	@Override
	public void list(final AsyncHandler<List<net.bluemind.authentication.api.APIKey>> handler) {
		String postUri = "";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"GET",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<List<net.bluemind.authentication.api.APIKey>>(handler) {
					@Override
			protected List<net.bluemind.authentication.api.APIKey> handleResponse(
							JSONValue jsonValue) {
				return new GwtSerDerUtils.ListSerDer<>(new net.bluemind.authentication.api.gwt.serder.APIKeyGwtSerDer()).deserialize( jsonValue );
			}
		});

	}


	@Override
	public void put(String displayName, String sid, final AsyncHandler<String> handler) {
		String postUri = "/_put";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		params.put("displayName", URL.encodeQueryString(""+displayName));
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = GwtSerDerUtils.STRING.serialize( sid);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"PUT",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<String>(handler) {
					@Override
			protected String handleResponse(
							JSONValue jsonValue) {
				return GwtSerDerUtils.STRING.deserialize( jsonValue );
			}
		});

	}

	public net.bluemind.authentication.api.IAPIKeysPromise promiseApi() {
		return new APIKeysEndpointPromise(this);
	}

}
